@@ -5,13 +5,6 @@
 
 import logging
 
-try:  # Python 2.7+
-    from logging import NullHandler
-except ImportError:
-
-    class NullHandler(logging.Handler):
-        def emit(self, record):
-            pass
-
+from logging import NullHandler
 
 logging.getLogger(__name__).addHandler(NullHandler())
