@@ -23,15 +23,13 @@ class DslMeta(type):
         if not hasattr(cls, "_type_name") or cls._type_name is None:
             return
 
-        key = cls.KEY
-
-        if key is None:
+        if cls.KEY is None:
             # and create a registry for subclasses
             if not hasattr(cls, "_classes"):
                 cls._classes = {}
-        elif key not in cls._classes:
+        elif cls.KEY not in cls._classes:
             # normal class, register it
-            cls._classes[key] = cls
+            cls._classes[cls.KEY] = cls
 
     @classmethod
     def get_dsl_type(cls, name):
@@ -41,16 +39,20 @@ class DslMeta(type):
             raise ValueError("DSL type %s does not exist." % name)
 
 
+def get_dsl_class(cls, name):
+    try:
+        return cls._classes[name]
+    except KeyError:
+        raise NotImplementedError(
+            "DSL class `{}` does not exist in {}.".format(name, cls._type_name)
+        )
+
+
 def ordered(obj):
     if isinstance(obj, dict):
         return sorted((k, ordered(v)) for k, v in obj.items())
     if isinstance(obj, list):
-        try:
-            return sorted(ordered(x) for x in obj)
-        except:
-            # can only happen on sort query parameter, for instance, where order matters
-            # ['title', {'category': {'order': 'desc'}}, '_score']
-            pass
+        return sorted(ordered(x) for x in obj)
     return obj
 
 
@@ -58,3 +60,14 @@ def equal_queries(d1, d2):
     """Compares if two queries are equivalent (do not consider nested list orders).
     """
     return ordered(d1) == ordered(d2)
+
+
+def equal_search(s1, s2):
+    if not isinstance(s1, dict) or not isinstance(s2, dict):
+        raise ValueError("not a search")
+    s1 = s1.copy()
+    s2 = s2.copy()
+    # sort order matters
+    if not s1.pop("sort", None) == s2.pop("sort", None):
+        return False
+    return equal_queries(s1, s2)
