@@ -160,11 +160,6 @@ class AggregationsResponseTestCase(PandaggTestCase):
                     "avg_nb_classes": 18.71,
                     "doc_count": 128,
                 },
-                ("multilabel", "gpc"): {
-                    "avg_f1_micro": 0.95,
-                    "avg_nb_classes": 183.21,
-                    "doc_count": 119,
-                },
                 ("multilabel", "preservationmethods"): {
                     "avg_f1_micro": 0.8,
                     "avg_nb_classes": 9.97,
@@ -205,13 +200,6 @@ class AggregationsResponseTestCase(PandaggTestCase):
                     "doc_count": 128,
                     "global_metrics.field.name": "ispracticecompatible",
                 },
-                {
-                    "avg_f1_micro": 0.95,
-                    "avg_nb_classes": 183.21,
-                    "classification_type": "multilabel",
-                    "doc_count": 119,
-                    "global_metrics.field.name": "gpc",
-                },
                 {
                     "avg_f1_micro": 0.8,
                     "avg_nb_classes": 9.97,
@@ -259,7 +247,7 @@ class AggregationsResponseTestCase(PandaggTestCase):
             "avg_f1_score": {"value": 0.815},
         }
         index_names, index_values = Aggregations(
-            data=raw_response, aggs=my_agg, index=None, client=None, query=None,
+            data=raw_response, aggs=my_agg, index=None, client=None, query=None
         ).to_tabular(index_orient=True, expand_sep=" || ")
 
         self.assertEqual(index_names, [])
@@ -304,11 +292,6 @@ class AggregationsResponseTestCase(PandaggTestCase):
                     "avg_nb_classes": 206.5,
                     "doc_count": 370,
                 },
-                ("multilabel", "gpc"): {
-                    "avg_f1_micro": 0.95,
-                    "avg_nb_classes": 183.21,
-                    "doc_count": 119,
-                },
                 ("multilabel", "ispracticecompatible"): {
                     "avg_f1_micro": 0.72,
                     "avg_nb_classes": 18.71,
