@@ -80,12 +80,6 @@ ES_AGG_RESPONSE = {
                             "doc_count": 128,
                             "key": "ispracticecompatible",
                         },
-                        {
-                            "avg_f1_micro": {"value": 0.95},
-                            "avg_nb_classes": {"value": 183.21},
-                            "doc_count": 119,
-                            "key": "gpc",
-                        },
                         {
                             "avg_f1_micro": {"value": 0.80},
                             "avg_nb_classes": {"value": 9.97},
@@ -135,9 +129,6 @@ EXPECTED_RESP_REPR = """root
 │       ├── avg_f1_micro                                0.89
 │       └── avg_nb_classes                             206.5
 └── classification_type=multilabel                      1797
-    ├── global_metrics.field.name=gpc                    119
-    │   ├── avg_f1_micro                                0.95
-    │   └── avg_nb_classes                            183.21
     ├── global_metrics.field.name=ispracticecompatible    128
     │   ├── avg_f1_micro                                0.72
     │   └── avg_nb_classes                             18.71
@@ -162,15 +153,6 @@ EXPECTED_NORMALIZED_RESPONSE = {
                     "level": "global_metrics.field.name",
                     "value": 128,
                 },
-                {
-                    "children": [
-                        {"key": None, "level": "avg_nb_classes", "value": 183.21},
-                        {"key": None, "level": "avg_f1_micro", "value": 0.95},
-                    ],
-                    "key": "gpc",
-                    "level": "global_metrics.field.name",
-                    "value": 119,
-                },
                 {
                     "children": [
                         {"key": None, "level": "avg_nb_classes", "value": 9.97},
